﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="Detelecine.cs" company="HandBrake Project (http://handbrake.fr)">
//   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
// </copyright>
// <summary>
//   Defines the Detelecine type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace HandBrake.Interop.Model.Encoding
{
	public enum Detelecine
	{
		Off = 0,
		Default = 2,
		Custom = 1
	}
}
